@@ -18,7 +18,7 @@ package GCImport::GCImportFolder;
 #
 #  You should have received a copy of the GNU General Public License
 #  along with GCstar; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 #
 ###################################################
 
@@ -479,7 +479,7 @@ use GCImport::GCImportBase;
             endPluginGetItemInfo:
            
             # Add the default value
-            my $defaultInfo = $self->{model}->getInitInfo;
+            my $defaultInfo = $self->{model}->getDefaultValues;
             
             my $info;
             # TODO : ask the user for order, or even for order on each fields
