@@ -11,15 +11,19 @@
     our %lang = (
     
         CollectionDescription => 'Weinsammlung',
-        Items => 'Wein',
+        Items => {0 => 'Wein',
+          1 => 'Wein',
+          X => 'Weine',
+          },
+
         NewItem => 'Neuer Wein',
-    
+
         Name => 'Name',
         Designation => 'Kennzeichnung',
         Vintage => 'Jahrgang',
         Vineyard => 'Weingut',
         Type => 'Art',
-        Grapes => 'Trauben',
+        Grapes => 'Rebsorte',
         Soil => 'Erde',
         Producer => 'Abfüller',
         Country => 'Land',
@@ -38,7 +42,7 @@
         BottleLabel => 'Etikett',
         Website => 'Website',
 
-        Tasted => 'Verkostet',
+        Tasted => 'verkostet',
         Comments => 'Kommentar',
         Serving => 'Portion',
         TastingField => 'Bemerkungen',
