@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Auteursrecht 2005-2007 Tian
+#  Auteursrecht 2005-2009 Tian
 #
 #  Dit bestand is onderdeel van GCstar.
 #
@@ -30,8 +30,8 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Where' => 'Waar moet het zoeken',
-        'Default' => 'Standaard Alexandria\'s Map',
+        'Where' => 'Waar moet ik zoeken',
+        'Default' => 'Standaard Alexandria\'s map',
         'Specified' => 'Map hieronder aangegeven',
      );
 }
