@@ -33,6 +33,9 @@
         'Charset' => 'Tekenset',
         'Header' => 'Negeer eerste lijn',
         'Separator' => 'Separator',
+        'Plugin' => 'Webpagina te gebruiken',
+        'UseFirst' => 'Selecteer de eerste bij een groot aantal resultaten',
+        'SearchField' => 'Search for items using',
      );
 }
 
