@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Auteursrecht 2005-2007 Tian
+#  Auteursrecht 2005-2009 Tian
 #
 #  Dit bestand is onderdeel van GCstar.
 #
@@ -32,7 +32,7 @@
 
     our %lang = (
     
-        CollectionDescription => 'TV-serie (afleveringen) collectie',
+        CollectionDescription => 'Collectie TV-serie (afleveringen)',
         Items => 'Afleveringen',
         NewItem => 'Nieuwe aflevering',
         NewSeries => 'Nieuwe serie',
